@@ -16,7 +16,7 @@
  * along with this library; if not, write to the Free Software Foundation,
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.47 2007/06/23 17:07:01 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/gperl.h,v 1.48 2007/08/01 18:00:34 kaffeetisch Exp $
  */
 
 #ifndef _GPERL_H_
@@ -235,8 +235,10 @@ SV * gperl_object_check_type (SV * sv, GType gtype);
 typedef gchar gchar_length;
 typedef gchar gchar_own;
 typedef gchar gchar_ornull;
+typedef gchar gchar_own_ornull;
 typedef char char_ornull;
 typedef char char_own;
+typedef char char_own_ornull;
 typedef GObject GObject_ornull;
 typedef GObject GObject_noinc;
 typedef gchar *GPerlFilename;
